@@ -5,45 +5,25 @@ class URI::Dispatch {
     use Ouch        qw( :traditional );
     use URI::Dispatch::Route;
     use version;
-    our $VERSION = qv( 1.4.1 );
+    our $VERSION = qv( 1.1 );
     
     has routes => (
         isa     => 'HashRef',
         is      => 'ro',
         builder => 'build_routes',
     );
-    has routes_ordered => (
-        isa     => 'ArrayRef',
-        is      => 'ro',
-        builder => 'build_routes_ordered',
-    );
     
     method build_routes {
         return {};
     }
-    method build_routes_ordered {
-        return [];
-    }
     
     
-    method add ( $path, $handler, $name? ) {
-        my %args = (
-                handler => $handler,
-                path    => $path,
+    method add ( $path, $handler ) {
+        my $route = URI::Dispatch::Route->new(
+                path => $path,
+                handler => $handler
             );
-        
-        $args{'name'} = $name
-            if defined $name;
-        
-        my $key   = $name // $handler;
-        my $route = URI::Dispatch::Route->new( %args );
-        
-        $self->routes->{ $key } = $route;
-        
-        push @{ $self->routes_ordered }, {
-            handler => $handler,
-            route   => $route,
-        };
+        $self->routes->{ $handler } = $route;
     }
     method dispatch ( $argument, @extra_args ) {
         my $method = 'get';
@@ -55,11 +35,6 @@ class URI::Dispatch {
             $path    = $argument->path;
             $request = $argument;
         }
-        elsif ( 'HASH' eq ref $argument ) {
-            $method  = lc( $argument->{'method'} // 'GET' );
-            $path    = $argument->{'path'} // '';
-            $request = $argument->{'request'};
-        }
         
         my( $handler, $options ) = $self->handler( $path );
         
@@ -81,9 +56,8 @@ class URI::Dispatch {
         }
     }
     method handler ( $path ) {
-        foreach my $option ( @{ $self->routes_ordered } ) {
-            my $route   = $option->{'route'};
-            my $handler = $option->{'handler'};
+        foreach my $handler ( keys %{ $self->routes } ) {
+            my $route   = $self->routes->{ $handler };
             my $options = $route->match_path( $path );
             
             return( $handler, $options )
@@ -136,13 +110,12 @@ URI::Dispatch - determine which code to execute based upon path
 
 =head1 METHODS
 
-=head2 add( I<path>, I<handler> [, I<name>] )
+=head2 add( I<path>, I<handler> )
 
-Add I<path> that can be handled by I<handler>, with an optional symbolic
-I<name>. The I<$path> string will be matched literally, except for the special
-markers described below. They have been specially chosen because they are not
-legal URI path characters, so should never break your actual chosen URI
-scheme.
+Add I<path> that can be handled by I<handler>. The I<$path> string will be
+matched literally, except for the special markers described below. They have
+been specially chosen because they are not legal URI path characters, so
+should never break your actual chosen URI scheme.
 
 =over
 
@@ -201,11 +174,6 @@ matches hour, minute and second separated by any of colons, periods or dashes
 
 matches anything
 
-=item B<0>
-
-matches nothing, an empty match; useful for binding to things like homepage
-matches with optional parameters (eg. '/#0[page-#id/]').
-
 =item (I<regexp>)
 
 matches a custom regular expression
@@ -244,13 +212,14 @@ Optional segments cannot be nested.
 
 =head3 Limitations
 
-Different handlers having the same path and multiple handlers having different
-paths will result in unpredictable behaviour.
+Adding a new path with the same I<handler> will overwrite the previous path.
+
+Different handlers having the same path will result in unpredictable
+behaviour.
 
 =head2 handler( I<path> )
 
-Determine which handler should be used for the given I<path>. The handlers
-are examined in the same order that they were given with C<add()>.
+Determine which handler should be used for the given I<path>.
 
 Returns the I<handler> string, and either an array of the captured elements,
 or a hash if the captures were named. For example, this code:
@@ -270,8 +239,7 @@ would return C<$captures> set to:
 
 Call the handler that matches the given argument, which can either be a
 simple string that represents a path, or it can be a L<Plack::Request>
-object.  The handlers are examined in the same order that they were given 
-with C<add()>.
+object.
 
 The handler is interpreted as a class, and the HTTP method is the subroutine
 within the class to call.
@@ -295,8 +263,7 @@ would set C<$response> to the return value of
 
 When C<dispatch()> is called with a L<Plack::Request> object, the path and
 method are determined automatically; and the object is passed to the handler
-before the captures, but after any extra arguments to C<dispatch()>. 
-For example:
+before the captures, but after any extra arguments to dispatch(). For example:
     
     $dispatch->add( '/tag/#name:slug', 'Tags::SingleTag' );
     
@@ -309,36 +276,10 @@ would set C<$response> to the return value of
 
     Tags::SingleTag::delete( $obj, $request, { name => 'perl' } );
 
-=head3 Hash reference
+=head2 url( I<handler>, I<$arguments> )
 
-When C<dispatch()> is called with a hash reference, the path, method and
-request objects are taken from that hash. Method defaults to GET if it is
-not specified; request is optional.
-
-As for a L<Plack::Request> object, the request object is passed to the 
-handler before the captures, but after any extra arguments to C<dispatch()>.
-For example:
-
-    $dispatch->add( '/tag/#name:slug', 'Tags::SingleTag' );
-    my $response = $dispatch->dispatch(
-        {
-            path    => '/tag/perl',
-            method  => 'HEAD',
-            request => $request_obj,
-        },
-        'extra_arg',
-    );
-
-would set C<$response> to the return value of
-
-    Tags::SingleTag::head( 'extra_arg', $request_obj, { name => 'perl' } );
-
-=head2 url( I<handler or name>, I<$arguments> )
-
-Build a path that would be accepted by the route specified by I<name> (or
-I<handler> if it wasn't added with a name parameter). When the path contains
-captures, you can pass them as an arrayref (or hashref if they are named
-captures).
+Build a path that I<handler> would accept. If the path contains captures,
+you can pass them as an arrayref (or hashref if they are named captures).
 
 The I<$arguments> are tested to ensure they would match. If they would not,
 an L<Ouch> exception is thrown. This can be caught in your code like so:
@@ -385,10 +326,6 @@ calling B<url()>.
 
 An unknown builtin parameter type was requested.
 
-=item 404
-
-No handler was found for the path when calling C<dispatch()>.
-
 =back
 
 =head1 AUTHOR
